==> igniteui-react-charts-16.16.1.tgz: package/esm5/lib/igr-stacked-spline-series.js <==
import { __extends } from "tslib";
import { IgrHorizontalStackedSeriesBase } from "./igr-horizontal-stacked-series-base";
import { StackedSplineSeries } from "./StackedSplineSeries";
import { ensureBool } from "igniteui-react-core";
/**
 * Represents a IgxDataChartComponent stacked spline series.
*/
var IgrStackedSplineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrStackedSplineSeries, _super);
    function IgrStackedSplineSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrStackedSplineSeries.prototype.createImplementation = function () {
        return new StackedSplineSeries();
    };
    Object.defineProperty(IgrStackedSplineSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrStackedSplineSeries.prototype, "isSplineShapePartOfRange", {
        /**
         * Gets or sets whether to include the spline shape in the axis range requested of the axis.
        */
        get: function () {
            return this.i.un;
        },
        set: function (v) {
            this.i.un = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrStackedSplineSeries.prototype, "isSpline", {
        /**
         * Gets whether the current series shows a spline shape.
        */
        get: function () {
            return this.i.eg;
        },
        enumerable: false,
        configurable: true
    });
    return IgrStackedSplineSeries;
}(IgrHorizontalStackedSeriesBase));
export { IgrStackedSplineSeries };

==> igniteui-react-charts-18.1.0.tgz: package/esm5/lib/igr-stacked-spline-series.js <==
import { __extends } from "tslib";
import { IgrHorizontalStackedSeriesBase } from "./igr-horizontal-stacked-series-base";
import { StackedSplineSeries } from "./StackedSplineSeries";
import { ensureBool } from "igniteui-react-core";
/**
 * Represents a IgxDataChartComponent stacked spline series.
*/
var IgrStackedSplineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrStackedSplineSeries, _super);
    function IgrStackedSplineSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrStackedSplineSeries.prototype.createImplementation = function () {
        return new StackedSplineSeries();
    };
    Object.defineProperty(IgrStackedSplineSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrStackedSplineSeries.prototype, "isSplineShapePartOfRange", {
        /**
         * Gets or sets whether to include the spline shape in the axis range requested of the axis.
        */
        get: function () {
            return this.i.ur;
        },
        set: function (v) {
            this.i.ur = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrStackedSplineSeries.prototype, "isSpline", {
        /**
         * Gets whether the current series shows a spline shape.
        */
        get: function () {
            return this.i.eh;
        },
        enumerable: false,
        configurable: true
    });
    return IgrStackedSplineSeries;
}(IgrHorizontalStackedSeriesBase));
export { IgrStackedSplineSeries };
